@@ -20,7 +20,7 @@ def validate_direct_address_list(l, enumeration_type):
         
         for k in max_values.keys():
             if d.get(k):
-                if max_values[k] < len(d.get(k)):
+                if max_values[k] < len(str(d.get(k))):
                     error = "%s : %s max allowable length %s." % (d.get('email'),  max_values[k])
                     errors.append(error)
     
