@@ -19,21 +19,21 @@ def validate_identifier_list(l, enumeration_type):
         }
     for d in l:
     
-        identifer_string = "%s %s %s issue by %s" % (d['identifier'],
+        identifer_string = "%s %s %s issued by %s" % (d['identifier'],
                                             d['code'], d['state'],
                                             d['issuer'])
 
         
         for k in max_values.keys():
             if d.get(k):
-                if max_values[k] < len(d.get(k)):
+                if max_values[k] < len(str(d.get(k))):
                     error = "%s : %s max allowable length %s." % (identifer_string, k, max_values[k])
                     errors.append(error)
     
     
         #check for required information
-        if d.get('code') not in ("", "01", "02", "04","05", "06", "07", "08"):
-            error = "%s : code  is not in ['', '01', '02', '04','05', '06', '07', '08']" % d.get('code')
+        if str(d.get('code', '')) not in ("", "01", "02", "04","05", "06", "07", "08", "1", "2", "4","5", "6", "7", "8"):
+            error = "%s : identifier code is not in ['', '01', '02', '04','05', '06', '07', '08']" % d.get('code')
             errors.append(error)
             
         #if state is provided then it should be valid.
